function TexFigure(savefile,filename,varargin)
% Program to insert a figure into a tex document.
% 
% Required: 
% Name of figure file (must specify path if in a different location from output file and extension, either .pdf or .eps).
% Name of output file.
% 
% Options:
% 'replace' 
% Table structure, which can include the fields:
% headtitle
% foottitle
% note
% label
% position (default is top of page)
% replace
% 
% Written by Johannes Wieland; an adaption of Gabriel Chodorow-Reich's Stata program and provided without any warranty
% This version: January 2015

% separating varargin into structure and text fields
for jj=1:length(varargin)
   if  isstruct(varargin{jj})==1
       tableprop   =    varargin{jj};
       varargin(jj)=    [];
   end
end
if exist('tableprop','var')==0
    tableprop   =   struct;
end

% Remaining varargin are figure proporites
figprop =   cell2struct(varargin,varargin,2);



% Options
if isfield(tableprop,'position')==0
	tableprop.position = '!t';
end

prestr  =   ' ';
poststr =   ' ';
if isfield(tableprop,'headtitle')
	prestr =  [prestr '\\caption{'  strrep(tableprop.headtitle,'_','\\_') '}\n'];
end
if isfield(tableprop,'foottitle')
	poststr =  [poststr '\\caption{' strrep(tableprop.foottitle,'_','\\_') '}\n'];
end
if isfield(tableprop,'label')
	poststr =  [poststr ' \\label{' strrep(tableprop.label,'_','-') '}\n'];
end
if isfield(tableprop,'note')
	poststr =  [poststr ' \\begin{minipage}{\\hsize} \\rule{0pt}{9pt} \n \\footnotesize\n \\vspace{-.15cm}\n\n \\noindent \n']; 
	poststr =  [poststr ' ' tableprop.note '\n'];
	poststr =  [poststr ' \\end{minipage}\n'];
end

% presstr
% poststr

% Replace option
if isfield(figprop,'replace')==1
	fid = fopen([savefile '.tex'],'w','n');
else 
	fid = fopen([savefile '.tex'],'a','n');
end


fprintf(fid,['\\begin{figure}[' tableprop.position ']\n']);
fprintf(fid,prestr);
fprintf(fid,['\\centerline{\\includegraphics[scale=0.5]{' filename '}}\n']);
fprintf(fid,poststr);
fprintf(fid,'\\end{figure}');
fclose(fid);

end