function franceGD_dynare(parabase,path,option)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%               Loading structures
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% parameter vector gets modified below
para = parabase;

%Creating variables from the parameter structure
para_names     =   fieldnames(para);
np=length(para_names);
for ii=1:np
    eval([para_names{ii} '=para.' para_names{ii} ';']);
end;

%Creating variables from the parameter structure
path_names     =   fieldnames(path);
np=length(path_names);
for ii=1:np
    eval([path_names{ii} '=path.' path_names{ii} ';']);
end;

%Creating variables from the parameter structure
option_names     =   fieldnames(option);
np=length(option_names);
for ii=1:np
    eval([option_names{ii} '=option.' option_names{ii} ';']);
end;

% loading saved steady-state values
eval(['load Steady/franceGD-' save_handle ])

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%       Creating objects for dynare
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% dynare objects given initial steady-state values
[var_ss,varexo,para] = franceGD_dynare_init(para,option,vars_ss);

% dynare objects given terminal steady-state values
var_ss_end = var_ss;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%       Initial conditions when not starting in steady-state
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

initstr = '';
% if starting from initial values, load them here now
if strcmp(option.initval,'init')==1
    var_ss
    initstr = '_init';
    
    % time interval
    law_end   = fin.e_Psii_1-1;
    law_start = 1;
    
    % loading simulation with temporary hours restrictions
    eval(['load Dynare/franceGD_simul' save_handle '_' solve_set ' M_ oo_;']);
   
    % enter initial condition in var_ss structure
    M_names_org = cellstr(M_.endo_names);
    M_names = M_names_org((M_.lead_lag_incidence(1,:)>0));
    for jj=1:length(M_names);
        currvar = find(strcmp(M_names_org,M_names{jj})==1);
        if strcmp(M_names{jj},'S')==0 && strcmp(M_names{jj},'rf')==0 && strcmp(M_names{jj},'Sd')==0
           newval = exp(oo_.endo_simul(currvar,law_end+1)) ;
        else
           newval = oo_.steady_state(currvar)+oo_.endo_simul(currvar,law_end+1);
        end
        eval(['var_ss1.' M_names{jj} '=' num2str(newval) ';'])
        
        % code for testing
%         eval(['oldval = var_ss.' M_names{jj} ';'])
%         disp(['oldval = ' num2str(oldval) ]) 
%         disp(['newval = ' num2str(newval) ]) 
%         
%         test = (newval-oldval)/oldval*100;
%         disp(['deviation = ' num2str(test) '%;'])
        
        
    end
    
    % updating shock process  
    for ii=1:length(path.rest_set)
        eval(['start.e_Psii_' num2str(ii) '    =   1;'])
        eval(['fin.e_Psii_' num2str(ii) '      =   0;'])
        eval(['depth.e_Psii_' num2str(ii) '    =   -rho_Psii*depth.e_Psii_' num2str(ii) ';'])
        eval(['repeat.e_Psii_' num2str(ii) '      =   0;']);
    end
    path.depth.e_rf     =   0;
    path.depth.e_a      =   0;
    
    % adjusting simulation duration
    simullen        =   simullen-law_end;

    var_ss1
    var_ss
%     duration

else
    var_ss1 = var_ss;
end


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%       Adjusting simulation for path
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% update this code with regular expression   
if strcmp(solve_set,'rec')==1
    for ii=1:nn
        eval(['depth.e_Psii_' num2str(ii) ' = 0;']);
        eval(['repeat.e_Psii_' num2str(ii) ' = 0;']);
    end
end



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%       Shocks for shooting in dynare
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% technology and risk premium are exogenous in deterministic simulation
exo_names = fieldnames(varexo);
for jj=1:length(exo_names);
    % take permanent shocks and add them to shockval structure
    eval(['currvar = exo_names{' num2str(jj) '}(3:end) ;']);
    
    % saving shock value at start, end and start/end-date
    eval(['shockval.e_' currvar '  = depth.e_' currvar ';'])
    eval(['shockend.e_' currvar '  = -depth.e_' currvar ';'])
    eval(['starte.e_' currvar '    = start.e_' currvar ';'])
    eval(['returne.e_' currvar '   = fin.e_' currvar ';'])
    eval(['repeate.e_' currvar '   = repeat.e_' currvar ';'])
    if eval(['returne.e_' currvar ])==0
        eval(['returne.e_' currvar '   = [];'])
        eval(['shockend.e_' currvar '  = [];'])
        eval(['repeate.e_' currvar '  = [];'])
    end
    if eval(['repeate.e_' currvar ])~=0
        eval(['shockend.e_' currvar '  = 0;'])
    end
end

% shockval
% shockend
% returne
% starte


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                           Setup for dynare file
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

para_names      =   fieldnames(para);  %cell array of parameter names
nn_para         =   length(para_names);   %number of parameters

%Creating a string with the parameter names
para_string   =   [];
for ii=1:nn_para
    para_string   =   [para_string para_names{ii} ' '];
end;

% Same procedure for steady-state of endogenous variables
var_ss_names      =   fieldnames(var_ss);  %cell array of parameter names
nn_var_ss         =   length(var_ss_names);   %number of parameters

%Creating a string with the parameter names
var_ss_string   =   [];
for ii=1:nn_var_ss
    var_ss_string       =   [var_ss_string var_ss_names{ii} ' '];
end;

% Same procedure for exogenous variables
varexo_names      =   fieldnames(varexo);  %cell array of parameter names
nn_varexo         =   length(varexo_names);   %number of parameters

%Creating a string with the parameter names
varexo_string   =   [];
for ii=1:nn_varexo
    varexo_string   =   [varexo_string varexo_names{ii} ' '];
end;

%Creating a string with the irf names
irf_string   =   [];
for jj=1:nn_var_ss
    for ii=1:nn_varexo
        irf_string   =   [irf_string var_ss_names{jj} '_' varexo_names{ii} ' '];
    end;
end


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                           Creating Dynare File
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

cd Dynare

% Creating the '.mod' file and starting writing in it
fid  =   fopen(['franceGD_' save_handle '_' solve_set initstr '.mod'],'w');

fprintf(fid,'// Dynare model file to calculate the impact of hours restriction in Great-Depression France\n');
fprintf(fid,'// Created by Johannes Wieland\n');
fprintf(fid,'// December 2015\n\n');

% number of sectors
eval(['fprintf(fid,''@#define nsec = ' num2str(option.nn) '\n\n'');'])

% Defining 
fprintf(fid,'\n// Endogenous variables;\n');
fprintf(fid,['var ' var_ss_string ';\n']);

fprintf(fid,'\n// Shocks;\n');
fprintf(fid,['varexo ' varexo_string ';\n\n']);

% adding parameters
fprintf(fid,'\n// Parameters;\n');
fprintf(fid,['parameters ' para_string ';\n']);

%Writing the parameter values
for ii=1:nn_para
    eval(['fprintf(fid,''' para_names{ii} '=%2.8f;\n'',' 'para.' para_names{ii} ');']);
end;

%Opening the model file and copying the model into the dynare file
fprintf(fid,'\n\nmodel;\n');

fid_mod     =   fopen('../franceGD_model_wage.m','r');
% fid_mod
while (1>0)
    modelline = fgetl(fid_mod);
        if (modelline==-1)  %end of file
            break 
        end;
    fprintf(fid,[modelline '\n']);
end;
fprintf(fid,'end;\n');
fclose(fid_mod);        %closing the model file



%Writing the steady state endogenous and exogenous variables as starting
%values
fprintf(fid,'\n\ninitval;\n');
for ii=1:nn_var_ss
    if strcmp(var_ss_names{ii},'rf')==1 || strcmp(var_ss_names{ii},'S')==1 || strcmp(var_ss_names{ii},'Sd')==1
        eval(['fprintf(fid,''' var_ss_names{ii} '=%2.9f;\n'',' 'var_ss.' var_ss_names{ii} ');']);
    else
        eval(['fprintf(fid,''' var_ss_names{ii} '=log(%2.9f);\n'',' 'var_ss.' var_ss_names{ii} ');']);
    end
end;
fprintf(fid,'end;\n');

%Checking the solution and making it calculate the steady state
fprintf(fid,'\nresid;\n');
% fprintf(fid,'\nsteady;\n');
fprintf(fid,'\ncheck;\n');


%Writing the terminal state in the case of deterministic simulation
if option.shooting==1
    if strcmp(option.initval,'init')==0
        fprintf(fid,'\n\nendval;\n');
        for ii=1:nn_var_ss
            if strcmp(var_ss_names{ii},'rf')==1 || strcmp(var_ss_names{ii},'S')==1 || strcmp(var_ss_names{ii},'Sd')==1
                eval(['fprintf(fid,''' var_ss_names{ii} '=%2.9f;\n'',' 'var_ss_end.' var_ss_names{ii} ');']);
            else
                eval(['fprintf(fid,''' var_ss_names{ii} '=log(%2.9f);\n'',' 'var_ss_end.' var_ss_names{ii} ');']);
            end
        end;
        fprintf(fid,'end;\n');
        %Checking the solution and making it calculate the steady state
        fprintf(fid,'\nsteady;\n');
        fprintf(fid,'\ncheck;\n');
    else
        fprintf(fid,'\n\nhistval;\n');
        for ii=1:length(M_names)
            if strcmp(M_names{ii},'rf')==1 || strcmp(M_names{ii},'S')==1 || strcmp(M_names{ii},'Sd')==1
                eval(['fprintf(fid,''' M_names{ii} '(0)=%2.9f;\n'',' 'var_ss1.' M_names{ii} ');']);
            else
                eval(['fprintf(fid,''' M_names{ii} '(0)=log(%2.9f);\n'',' 'var_ss1.' M_names{ii} ');']);
            end
        end;
        fprintf(fid,'end;\n');
    end
end

%Defining the variances/paths of the shocks
fprintf(fid,'\nshocks;\n');
if option.shooting==0
    for ii=1:nn_varexo    
        eval(['fprintf(fid,''' 'var ' varexo_names{ii} '=sigma_' varexo_names{ii} '^2;\n''' ');']);
    end;
elseif option.shooting==1
    for ii=1:nn_varexo    
        eval(['fprintf(fid,''' 'var ' varexo_names{ii} ';\n''' ');']);
        eval(['currstart = start.' varexo_names{ii} ';']);
        eval(['currreturn = returne.' varexo_names{ii} ';']);
        eval(['currrepeat = repeat.' varexo_names{ii} ';']);
        if currrepeat~=0
            eval(['fprintf(fid,''' 'periods ' num2str(round(currstart)) ' ' num2str(round(currstart)+1) ':' num2str(round(currreturn)-1) ' ' num2str(round(currreturn)) ' ;\n''' ');']);
            eval(['fprintf(fid,''' 'values %2.9f %2.9f %2.9f ;\n'',' 'shockval.' varexo_names{ii} ' ,' 'currrepeat ,' 'shockend.' varexo_names{ii} ');']);
        elseif currreturn>0
            eval(['fprintf(fid,''' 'periods ' num2str(round(currstart)) ' ' num2str(round(currreturn)) ' ;\n''' ');']);
            eval(['fprintf(fid,''' 'values %2.9f %2.9f ;\n'',' 'shockval.' varexo_names{ii} ' ,' 'shockend.' varexo_names{ii} ');']);
        else
            eval(['fprintf(fid,''' 'periods ' num2str(round(currstart)) ' ;\n''' ');']);
            eval(['fprintf(fid,''' 'values %2.9f ;\n'',' 'shockval.' varexo_names{ii} ');']);
        end
    end;
end
fprintf(fid,'end;\n');


%Solving the model
if option.shooting==0
    if option.nn>2
        fprintf(fid,['\nstoch_simul(order=1, irf=' num2str(irflen) ', nofunctions, nomoments, nocorr, nograph);']); %,nograph
    else
        fprintf(fid,['\nstoch_simul(order=1, nomoments, irf=' num2str(irflen) ', nocorr);']); %,nograph
    end
    
    % Saving output
    fprintf(fid,['\n save franceGD_irfs_' save_handle ' ' irf_string ' M_ oo_;']); %,nograph
    
elseif option.shooting==1
    fprintf(fid,['\n simul(periods=' num2str(simullen) ',maxit=' num2str(maxiter) ');']);
    fprintf(fid,['\n save franceGD_simul'  save_handle '_' solve_set initstr ' M_ oo_;']); %,nograph
end

%Closing the dynare file
fclose(fid);
cd ..

%running the dynare file
cd Dynare;
eval(['dynare franceGD_' save_handle '_' solve_set initstr '.mod noclearall']);
% eval(['load search_irfs_' num2str(zz) ';'])
cd ..;



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                  Joining Dynare files
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

if strcmp(option.initval,'init')==1
    
    % loading initial simulation
    eval(['load Dynare/franceGD_simul' save_handle '_' solve_set ' M_ oo_;']);
    eval(['save Dynare/franceGD_simul' save_handle '_' solve_set 'tempsave M_ oo_;']);
    oo_old = oo_;
    
    % loading new simulation
    eval(['load Dynare/franceGD_simul' save_handle '_' solve_set  initstr ' M_ oo_;']);
    oo_.endo_simul = [oo_old.endo_simul(:,1:law_end+1) oo_.endo_simul(:,2:end)];
    
    % saving new data
    eval(['save Dynare/franceGD_simul' save_handle '_' solve_set ' M_ oo_;']);
    
end
