function [var_ss,varexo,para] = franceGD_dynare_init(para,option,vars_ss_set)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                 Determine steady-state of multi-sector search model
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%Creating variables from the parameter structure
para_names     =   fieldnames(para);
np=length(para_names);
for ii=1:np
    eval([para_names{ii} '=para.' para_names{ii} ';']);
end;

%Creating variables from the parameter structure
option_names     =   fieldnames(option);
np=length(option_names);
for ii=1:np
    eval([option_names{ii} '=option.' option_names{ii} ';']);
end;

% Unloading structure
vars_ss_set_names     =   fieldnames(vars_ss_set);
np=length(vars_ss_set_names);
for ii=1:np
    eval([vars_ss_set_names{ii} ' =vars_ss_set.' vars_ss_set_names{ii} ';']);
end;

% exogenous variables not in structure
e_a     =   0;
e_rf    =   0;
e_Psii  =   zeros(1,option.nn);

% set of variables to put in structure when nn=1
varset1 = {'Yi', 'Ni', 'Ki', 'WPi', 'mui','Hpci', 'bi', 'Hi', 'Fi', 'Pii', 'Piwi', 'Preli', 'Deltai','Psii','e_Psii'};

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%          Rewrite in terms of dynare variables
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% defining individual and aggregate variables
varset={};

% variables used in simulation
allvarset=vars_ss_set_names;
shockset={'e_rf','e_a','e_Psii'};

% creating structure of variables
for zz=1:length(allvarset);
    
    eval(['lenvar = length(' allvarset{zz} ');'])
    
    % aggregate variables
    if lenvar==1 && isempty(strmatch(allvarset{zz}, varset1, 'exact'))
        eval([allvarset{zz} '=' allvarset{zz} '(1);']);
        varset = {varset{:}, allvarset{zz} };
                
    % industry variables    
    else
        disp(allvarset{zz})
        eval(allvarset{zz})
        for ii=1:option.nn
            eval([allvarset{zz} '_' num2str(ii) '=' allvarset{zz} '(' num2str(ii) ');']);
            varset = {varset{:}, [allvarset{zz} '_' num2str(ii) ]};
        end
    end   
    
end


% shocks
varexoset={};
for zz=1:length(shockset);
    
    eval(['lenvar = length(' shockset{zz} ');'])
    
    % aggregate shocks
    if lenvar==1 && isempty(strmatch(shockset{zz}, varset1, 'exact'))
        eval([shockset{zz} '=' shockset{zz} '(1);']);
        varexoset = {varexoset{:}, shockset{zz} };
               
    % industry shocks
    else
        for ii=1:option.nn
            eval([shockset{zz} '_' num2str(ii) '=' shockset{zz} '(' num2str(ii) ');']);
            varexoset = {varexoset{:}, [shockset{zz} '_' num2str(ii)] };
        end
        
    end
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%          Entering variables in structure
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Putting variables into structure
np=length(varset);
for ii=1:np
    eval(['var_ss.' varset{ii} '=' varset{ii} ';']);
end;

% Putting shocks into structure
np=length(varexoset);
for ii=1:np
    eval(['varexo.' varexoset{ii} '=' varexoset{ii} ';']);
end;

% Putting new parameters into structure: volatility of shocks
for zz=1:length(shockset);
    eval(['shvar = ' shockset{zz} ';']);
    if length(shvar)>1  || isempty(strmatch(shockset{zz}, varset1, 'exact'))==0
        for jj=1:option.nn
            eval(['para.sigma_' shockset{zz} '_' num2str(jj) ' = 0.01;']);
        end
    else
        eval(['para.sigma_' shockset{zz} ' = 0.01;']);
    end
end

% Putting new parameters into structure: steady-state values
para.Ybar = vars_ss_set.Y;
para.Rbar = vars_ss_set.R;

% Putting new parameters into structure: industry taste, wage and technology parameters
for zz=1:option.nn;
   eval(['para.tau_' num2str(zz) '= para.tau(1,' num2str(zz) ');']);
end


% New parameter vector: remove taste and technology vectors (inputted
% individually above)
para    =   rmfield(para,'tau');
para    =   rmfield(para,'a');

end