%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%               NKDMP model
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


clear all;
close all;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%               Options for code
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% baseline options
option.nn           =   22;                     % Number of sectors
option.solve_set    =   {'rec','rechours'};     % Two experiments we run: recession and recession with hours restriction. The IRFs we plot are the difference between the two. In our baseline set-up the recession depth is zero, so it is equivalent to just running the rechours simulation.
option.shooting     =   1;                      % 0=linearize and IRF, 1=deterministic simulation (shooting)

% Robustness options             
option.lawmatch     =   '';'actual';            % Robustness check with actual hours decline rather than statutory
option.habit        =   '';'habit';             % Robustness check with habit formation
option.pindex       =   '';'pindex';            % Robustness check with inflation indexation
option.wrigid       =   '';'wrigid';            % Robustness check with wage rigidity
option.response     =   '';'response';          % Robustness check with actual interest rate response
option.initval      =   '';'on';                % Robustness check with imperfect foresight of termination
option.robustplot   =   '';'on';                % Plot all robustness checks (need to run each of them first)


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%               Loading parameters
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


set(0,'defaultaxesfontsize',20);
set(0,'defaulttextfontsize',20);

clc;

% Loading parameters
cd ../Parameters/
run parameters
load parameters.mat
cd ../Code

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%               Implementing options
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

 
option.save_handle = ['nsec' num2str(option.nn) option.lawmatch option.initval option.habit option.pindex option.wrigid option.response];

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%               Solving for the steady-state
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

franceGD_steady(para,option)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%               Solving for dynamcis
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

franceGD_dynare_parallel(para,path,option)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%              Plotting outcomes
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if option.shooting==1
    irf=franceGD_plot(para,path,option);
end
