
///////////////////////////////////////////////////////////////////////////                        
/////////                Industry Block                         ///////////
///////////////////////////////////////////////////////////////////////////

// exo variables: Q, Y, K, a, Psii, 
// endo variables: Yi, Ni, Ki, mui, bi, Hi, Fi, Pii, Pirel, Deltai, Pi, N

// looping over all industries
@#for ii in 1:nsec

    // (1) Relative Demand   
    exp(Yi_@{ii})   =   tau_@{ii} * exp(Preli_@{ii})^(-thetta) * exp(Y);
    
    // (2) Production function
    exp(Yi_@{ii})   =   exp(a) * ( exp(Ni_@{ii}) * exp(Psii_@{ii}) * Hbar )^(1-alfa) * exp(Ki_@{ii})^alfa / exp(Deltai_@{ii});   
    
    // (3) Relative use of inputs
    exp(Ki_@{ii})    =   exp(K)/exp(N)*exp(Ni_@{ii}) ;
    
    // (4) Marginal cost
    exp(mui_@{ii})   =   alfabar*exp(Rk)^alfa * exp(WP)^(1-alfa) / ( ( exp(Psii_@{ii}) * Hbar )^(1-alfa) * exp(a) );
    
    // (5) Real reset price
    exp(bi_@{ii})     =   zetta / (zetta-1) * exp(Fi_@{ii}) / exp(Hi_@{ii});
    
    // (6) Recursive characterization 1
    exp(Fi_@{ii})     =   exp(Yi_@{ii}) * exp(mui_@{ii}) * exp(Pii_@{ii})^zetta + (1-xi) * exp(Q) * exp(Pii_@{ii}(+1))^zetta * exp(Fi_@{ii}(+1));
    
    // (7) Recursive characterization 2
    exp(Hi_@{ii})     =   exp(Yi_@{ii}) * exp(Preli_@{ii}) * exp(Pii_@{ii})^(zetta-1) + (1-xi) * exp(Q) * exp(Pii_@{ii}(+1))^(zetta-1) * exp(Hi_@{ii}(+1));
    
    // (8) Industry inflation
    exp(Pii_@{ii})   =   ( xi*exp(bi_@{ii})^(1-zetta) + (1-xi) )^(1/(1-zetta));
    
    // (9) Price dispersion
    exp(Deltai_@{ii})   =   (1-xi)*exp(Deltai_@{ii}(-1))*exp(Pii_@{ii})^zetta + xi*exp(bi_@{ii})^(-zetta)*exp(Pii_@{ii})^zetta;
    
    // (10) Industry inflation and relative price
    exp(Pii_@{ii})   =   exp(Pi) * exp(Preli_@{ii}) / exp(Preli_@{ii}(-1));
    
    // (11) Hours per person
    exp(Hpci_@{ii})  =  exp(Psii_@{ii}) * Hbar;
    
@#endfor

// (12) Aggregate prices
1    =   (
            @#for ii in 1:nsec
                +tau_@{ii}*(exp(Preli_@{ii}))^(1-thetta)
            @#endfor 
         )^(1/(1-thetta)) ; 
         
// (13) Aggregate labor
exp(N)    =   (
            @#for ii in 1:nsec
                +(exp(Ni_@{ii}))
            @#endfor 
         ) ;          

///////////////////////////////////////////////////////////////////////////                        
/////////                      NK Block                         ///////////
///////////////////////////////////////////////////////////////////////////

// exo vars: Pi, rf, N
// endo vars: Y, C, Q, I, K, WP, Pk, R, lambda

//////////////////////////////////////////////////                        
// 1. Consumers
//////////////////////////////////////////////////

// (1) Euler equation
1 = exp(Q)* (exp(R)+rf ) / ( exp(Pi(+1))  ) ;

// (2) sdf
exp(Q)      =   betta* exp(lambda(+1)) / exp(lambda);

// (3) marginal utility
exp(lambda) =   (( exp(C) - habit* exp(C(-1)) )/(1-habit))^(-siggma) ;

// (4) labor supply
exp(WPStar)     =   chi * exp(N)^etta / exp(lambda);

// (5) wage rigidity
exp(WP)     =   exp(WPStar);

//////////////////////////////////////////////////                        
// 2. Capital accumulation
//////////////////////////////////////////////////
 
// (5) Law of motion for capital
exp(K)      =   (1-delta)*exp(K(-1)) + exp(I)*( 1 - S );

// (6) Return to capital
exp(Pk)     =   exp(Q)*( exp(Rk(+1)) + (1-delta)*exp(Pk(+1)) );

// (7) Optimal investment
1   =   exp(Pk) * (  1 - S - exp(I)/exp(I(-1))*Sd )
        +exp(Q) * exp(Pk(+1)) * (exp(I(+1))/exp(I))^2 * Sd(+1) ;

// (9) Capital adjustment costs
S  =    0.5*exp( psi^0.5* (exp(I)/exp(I(-1)) -1 ) ) + 0.5*exp( -psi^0.5* (exp(I)/exp(I(-1)) -1 ) ) - 1;       

// (10) Capital adjustment costs: first derivative
Sd  =    0.5*psi^0.5* ( exp( psi^0.5* (exp(I)/exp(I(-1)) -1 ) ) - exp( -psi^0.5* (exp(I)/exp(I(-1)) -1 ) ) ) ;       
        
// (11) Relative use of inputs
exp(K)    =   alfa/(1-alfa) * exp(WP) / exp(Rk) * exp(N);

//////////////////////////////////////////////////                        
// 3. Government
//////////////////////////////////////////////////
          
// (12) Interest rate rule:
exp(R) = max(  exp(RStar) , ibar );

// (13) Unconstrained interest rate
exp(RStar) = (betta^-1*exp(Pi)^phipi)^(1-rho_R)*exp(RStar(-1))^(rho_R);

//////////////////////////////////////////////////                        
// 4. Market clearing
//////////////////////////////////////////////////
          
// (14) National income accounting identity:
exp(Y) = exp(C) + exp(I);

///////////////////////////////////////////////////////////////////////////                        
/////////                Exogenous variables                    ///////////
///////////////////////////////////////////////////////////////////////////

// (1) Productivity shock
exp(a) =  exp(a(-1))^rho_a * exp(e_a);

// (2) Discount factor shock
rf      = rho_rf*rf(-1) + e_rf ;

// (3) Hours restrictions
@#for ii in 1:nsec
    exp(Psii_@{ii})  =   exp(Psii_@{ii}(-1))^(rho_Psii)*exp(e_Psii_@{ii});
@#endfor

