
///////////////////////////////////////////////////////////////////////////                        
/////////                Industry Block                         ///////////
///////////////////////////////////////////////////////////////////////////

// exo variables: Q, Y, a, Psii, K
// endo variables: Yi, Ni, Ki, WPi, Piwi, mui, Pii, Pirel, Deltai, Hpci, Pi, N, WP

// looping over all industries
@#for ii in 1:nsec

    // (1) Relative Demand   
    exp(Yi_@{ii})   =   tau_@{ii} * exp(Preli_@{ii})^(-thetta) * exp(Y);
    
    // (2) Production function
    exp(Yi_@{ii})   =   exp(a) * ( exp(Ni_@{ii}) * exp(Psii_@{ii}) * Hbar )^(1-alfa) * exp(Ki_@{ii})^alfa / exp(Deltai_@{ii});   
    
    // (3) Relative use of inputs
    exp(Ki_@{ii})    =   alfa/(1-alfa) * exp(WPi_@{ii}) / exp(Rk) * exp(Ni_@{ii});
    
    // (4) Industry nominal wage
    //exp(WPi_@{ii})   =    chi * exp(Ni_@{ii})^etta  * exp(Deltai_@{ii})^etta  / exp(lambda);
    0   =   exp(Ni_@{ii}) * ( -zeta_w * exp(WPi_@{ii}) + zeta_w * chi * tau_@{ii}^(-etta) * exp(Ni_@{ii})^etta / exp(lambda) -  phi_w * exp(Piwi_@{ii}) * (exp(Piwi_@{ii})-1) ) + exp(Q) * exp(Ni_@{ii}(+1)) * phi_w * exp(Piwi_@{ii}(+1)) * ( exp(Piwi_@{ii}(+1)) -1 ) ;
    
    // (5) Industry wage inflation
    exp(Piwi_@{ii})   =    exp(WPi_@{ii})/exp(WPi_@{ii}(-1))/exp(Pi);
    
    // (6) Marginal cost
    exp(mui_@{ii})   =   alfabar*exp(Rk)^alfa * exp(WPi_@{ii})^(1-alfa) / ( ( exp(Psii_@{ii}) * Hbar )^(1-alfa) * exp(a) );
    
    // (7) Industry inflation
    //exp(Pii_@{ii}) * (exp(Pii_@{ii}) - exp(Pii_@{ii}(-1))^pindex)   =   ( (1-zetta)/rotac * exp(Preli_@{ii}) + zetta/rotac * min(exp(mui_@{ii}),4) ) + ( exp(Q) * exp(Yi_@{ii}(+1)) / exp(Yi_@{ii}) * exp(Pii_@{ii}(+1)) * (exp(Pii_@{ii}(+1)) - exp(Pii_@{ii})^pindex) );
    //exp(Pii_@{ii}) * (exp(Pii_@{ii}) - 1)   =   ( (1-zetta)/rotac * exp(Preli_@{ii}) + zetta/rotac * min(exp(mui_@{ii}),5) ) + ( exp(Q) * exp(Yi_@{ii}(+1)) / exp(Yi_@{ii}) * exp(Pii_@{ii}(+1)) * (exp(Pii_@{ii}(+1)) - 1) );
    log( exp(Pii_@{ii})^2 / exp(Q) )   =   log( (exp(Pii_@{ii}) * exp(Pii_@{ii}(-1))^pindex )/exp(Q) + ( (1-zetta)/rotac * exp(Preli_@{ii}) + zetta/rotac * exp(mui_@{ii}) )/exp(Q) + (  exp(Yi_@{ii}(+1)) / exp(Yi_@{ii}) * exp(Pii_@{ii}(+1)) * (exp(Pii_@{ii}(+1)) - exp(Pii_@{ii})^pindex) ));
    
    // (8) Price dispersion
    //exp(Deltai_@{ii})   =   (1-xi)*exp(Deltai_@{ii}(-1))*exp(Pii_@{ii})^zetta + xi*exp(bi_@{ii})^(-zetta)*exp(Pii_@{ii})^zetta;
    exp(Deltai_@{ii})   =  1;
    
    // (9) Industry inflation and relative price
    exp(Pii_@{ii})   =   exp(Pi) * exp(Preli_@{ii}) / exp(Preli_@{ii}(-1));
    
    // (10) Hours per person
    exp(Hpci_@{ii})  =  exp(Psii_@{ii}) * Hbar;
    
@#endfor

// (11) Aggregate prices
1    =   (
            @#for ii in 1:nsec
                +tau_@{ii}*(exp(Preli_@{ii}))^(1-thetta)
            @#endfor 
         )^(1/(1-thetta)) ; 
         
// (12) Aggregate labor
exp(N)    =   (
            @#for ii in 1:nsec
                +tau_@{ii}^(-etta) *(exp(Ni_@{ii}))^(1+etta)
            @#endfor 
         )^(1/(1+etta)) ;  
         
// (13) Aggregate capital
exp(K(-1))    =   (
            @#for ii in 1:nsec
                +(exp(Ki_@{ii}))
            @#endfor 
         ) ;  
         
// (14) Aggregate wage
exp(WP)    =   (
            @#for ii in 1:nsec
                +tau_@{ii}*(exp(WPi_@{ii}))^((1+etta)/etta)
            @#endfor 
         )^(etta/(1+etta)) ; 
         


///////////////////////////////////////////////////////////////////////////                        
/////////                      NK Block                         ///////////
///////////////////////////////////////////////////////////////////////////

// exo vars: Pi, rf, N
// endo vars: Y, C, Q, I, K, WP, Pk, R, lambda

//////////////////////////////////////////////////                        
// 1. Consumers
//////////////////////////////////////////////////

// (1) Euler equation
1 = exp(Q)* (exp(R)+rf ) / ( exp(Pi(+1))  ) ;

// (2) sdf
exp(Q)      =   betta* exp(lambda(+1)) / exp(lambda);

// (3) marginal utility
exp(lambda) =   (( exp(C) - habit* exp(C(-1)))/(1-habit))^(-siggma) ;
//exp(lambda) =  ( ( exp(C) - habit* exp(C(-1)) )^(-siggma) -  betta*habit*( exp(C(+1)) - habit* exp(C) )^(-siggma) )/ ((1-habit)^(-siggma)*(1-betta*habit)) ;


//////////////////////////////////////////////////                        
// 2. Capital accumulation
//////////////////////////////////////////////////
 
// (4) Law of motion for capital
exp(K)      =   (1-delta)*exp(K(-1)) + exp(I)*( 1 - S );

// (5) Return to capital
exp(Pk)     =   exp(Q)*( exp(Rk(+1)) + (1-delta)*exp(Pk(+1)) );
//exp(Pk)     =   exp(Q)*( exp(Rk(+1)) + (1-delta)*exp(Pk(+1)) + (exp(I(+1))/exp(K))^2 * Sd(+1)  );

// (6) Optimal investment
1   =   exp(Pk) * (  1 - S - exp(I)/exp(I(-1))*Sd )
        +exp(Q) * exp(Pk(+1)) * (exp(I(+1))/exp(I))^2 * Sd(+1) ;
//1   =   exp(Pk) * (  1 - S - exp(I)/exp(K(-1))*Sd ) ;
        
// (7) Capital adjustment costs
S  =    0.5*exp( psi^0.5* (exp(I)/exp(I(-1)) -1 ) ) + 0.5*exp( -psi^0.5* (exp(I)/exp(I(-1)) -1 ) ) - 1;       
//S  =    0.5*psi * ( exp(I)/ exp(K(-1)) - delta )^2 ;       
//S  =    0.5*exp( psi^0.5* (exp(I)/exp(K(-1)) -delta ) ) + 0.5*exp( -psi^0.5* (exp(I)/exp(K(-1)) -delta ) ) - 1;       

// (8) Capital adjustment costs: first derivative
Sd  =    0.5*psi^0.5* ( exp( psi^0.5* (exp(I)/exp(I(-1)) -1 ) ) - exp( -psi^0.5* (exp(I)/exp(I(-1)) -1 ) ) ) ;       
//Sd  =   psi * ( exp(I)/ exp(K(-1)) - delta );       
//Sd  =    0.5*psi^0.5* ( exp( psi^0.5* (exp(I)/exp(K(-1)) -delta ) ) - exp( -psi^0.5* (exp(I)/exp(K(-1)) -delta ) ) ) ;       

//////////////////////////////////////////////////                        
// 3. Government
//////////////////////////////////////////////////
          
// (9) Interest rate rule:
exp(R) = max(  exp(RStar) , ibar );
//exp(R)  =   Rbar;

// (10) Unconstrained interest rate
exp(RStar) = (Rbar*exp(Pi)^phipi*(exp(Y)/Ybar)^phiy)^(1-rho_R)*exp(R(-1))^(rho_R);

//////////////////////////////////////////////////                        
// 4. Market clearing
//////////////////////////////////////////////////
          
// (11) National income accounting identity:
exp(Y) = exp(C) + exp(I);

///////////////////////////////////////////////////////////////////////////                        
/////////                Exogenous variables                    ///////////
///////////////////////////////////////////////////////////////////////////

// (1) Productivity shock
exp(a) =  exp(a(-1))^rho_a * exp(e_a);

// (2) Discount factor shock
rf      = rho_rf*rf(-1) + e_rf ;

// (3) Hours restrictions
@#for ii in 1:nsec
    exp(Psii_@{ii})  =   exp(Psii_@{ii}(-1))^(rho_Psii)*exp(e_Psii_@{ii});
@#endfor

