function irf=franceGD_plot(para,path,option)

close all
set(0,'defaultaxesfontsize',16);
set(0,'defaulttextfontsize',16);
figsize = [100 100 500 400];
figsize2 = [100 100 1200 400];
set(0, 'DefaultFigurePosition', figsize);
set(0,'defaultfigurecolor',[1 1 1])


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%               Loading structures
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%Creating variables from the parameter structure
para_names     =   fieldnames(para);
nn=length(para_names);
for ii=1:nn
    eval([para_names{ii} '=para.' para_names{ii} ';']);
end;

%Creating variables from the parameter structure
path_names     =   fieldnames(path);
nn=length(path_names);
for ii=1:nn
    eval([path_names{ii} '=path.' path_names{ii} ';']);
end;

%Creating variables from the parameter structure
option_names     =   fieldnames(option);
nn=length(option_names);
for ii=1:nn
    eval([option_names{ii} '=option.' option_names{ii} ';']);
end;

save_handle_new = ['-' save_handle];

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%              Plot variables
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

styleset3={'''bo-''','''rd--''','''gs-.''','''kv:''','''c^-''','''mp--'''};
save_file_set=[];

irflen=maxplotlen+1;
irfx=0:1:maxplotlen;

% if strcmp(option.initval,'on')==1
%     initstr = '_init';
% end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%    Differential responses of hours with recession and without recession
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% putting simulation results in IRF structure
irf = struct;
for kk=1:length(solve_set)
    eval(['load Dynare/franceGD_simul' save_handle '_' solve_set{kk} '.mat'])
    var_names = cellstr(M_.endo_names);
    for mm=1:length(var_names)
        eval(['irf.' solve_set{kk} '.' var_names{mm} '=oo_.endo_simul(' num2str(mm) ',:);'])
    end
    
    % adding price level
    currloc = find(strcmp(var_names,'Pi')==1);
    eval(['irf.' solve_set{kk} '.P =log(cumprod(exp(oo_.endo_simul(currloc,:))));'])
    
    % adding nominal wage
    currloc = find(strcmp(var_names,'WP')==1);
    eval(['irf.' solve_set{kk} '.W = irf.' solve_set{kk} '.WP + irf.' solve_set{kk} '.P;'])
end

% differential impact of hours conditional on recession
var_names= fieldnames(irf.rec);
for mm=1:length(var_names)
    eval(['irf.hourscond.' var_names{mm} '=irf.rechours.' var_names{mm} ' - irf.rec.' var_names{mm} ' + irf.rec.' var_names{mm} '(1);'])
end
solve_set = {solve_set{:},'hourscond'};

% saving output
eval(['save ../Output/simulation/franceGD_simul' save_handle '.mat irf'])

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%              Figure 1: Hours restrictions
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

colorsset = distinguishable_colors(option.nn);

figure
legendset = {'test'};
legenstr = [];
sameshock = 0;
vv=0;
for pp=1:option.nn
    % creating legend
    if pp>1 && pp<option.nn
        sameshockold = sameshock;
        sameshock = (path.rest_set(pp)==path.rest_set(pp-1));
        if sameshockold==1 && sameshock==0
            legenstr=[legenstr ' through ' num2str(pp-1)];
            legendset={legendset{:},legenstr};
            legenstr = [];
        elseif sameshockold==0 && sameshock==1
            legenstr=['Industry ' num2str(pp-1)];
        elseif sameshockold==0 && sameshock==0
            legenstr=['Industry ' num2str(pp-1)];
            legendset={legendset{:},legenstr};
            legenstr = [];
        end
    elseif pp==option.nn
        sameshockold = sameshock;
        sameshock = (path.rest_set(pp)==path.rest_set(pp-1));
        if sameshock==1
            legenstr={[legenstr ' through ' num2str(pp-1)]};
        else
            legenstr={['Industry ' num2str(pp-1)];['Industry ' num2str(pp)]};
        end
        legendset={legendset{:},legenstr{:}};
        legenstr = [];
    else
        sameshock = 0;
        legenstr = ['Industry 1'];
    end
    % plotting hours restrictions
    if sameshock==0
        vv=vv+1;
        eval(['plot(irfx,exp(irf.hourscond.Psii_' num2str(pp) '(1+irfx)).*48,''Color'',colorsset(' num2str(vv) ',:),''Linewidth'',3)'])
        hold on
    end
end

legend(legendset{2:end},'Location','East')
xlabel('Month')
ylabel('Hours per worker by industry')
xlim([0 maxplotlen])
ylim([38 50])
hold off

filename  = ['input-files/irf-franceGD-hours' save_handle_new];
save_file = ['../Output/' filename];
export_fig([save_file '.eps'],'-transparent');
figprop.headtitle   =   ['Impulse Response Functions of Hours Per Capita'];
figprop.label   =   ['fig:' filename];
TexFigure(save_file,[filename '.eps'],'replace',figprop);
save_file_set   =   [save_file_set ' ' filename '.tex'];
clear figprop;
% stop here;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%      Figure 1b (appendix): Expected hours restrictions if different
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

if strcmp(option.initval,'on')==1
    eval(['load Dynare/franceGD_simul' save_handle '_rechourstempsave.mat'])
    var_names = cellstr(M_.endo_names);
    for mm=1:length(var_names)
        eval(['irfold.rechours.' var_names{mm} '=oo_.endo_simul(' num2str(mm) ',:);'])
    end
    
    figure
    legendset = {'test'};
    legenstr = [];
    sameshock = 0;
    vv=0;
    for pp=1:option.nn
        % creating legend
        if pp>1 && pp<option.nn
            sameshockold = sameshock;
            sameshock = (path.rest_set(pp)==path.rest_set(pp-1));
            if sameshockold==1 && sameshock==0
                legenstr=[legenstr ' through ' num2str(pp-1)];
                legendset={legendset{:},legenstr};
                legenstr = [];
            elseif sameshockold==0 && sameshock==1
                legenstr=['Industry ' num2str(pp-1)];
            elseif sameshockold==0 && sameshock==0
                legenstr=['Industry ' num2str(pp-1)];
                legendset={legendset{:},legenstr};
                legenstr = [];
            end
        elseif pp==option.nn
            sameshockold = sameshock;
            sameshock = (path.rest_set(pp)==path.rest_set(pp-1));
            if sameshock==1
                legenstr={[legenstr ' through ' num2str(pp-1)]};
            else
                legenstr={['Industry ' num2str(pp-1)];['Industry ' num2str(pp)]};
            end
            legendset={legendset{:},legenstr{:}};
            legenstr = [];
        else
            sameshock = 0;
            legenstr = ['Industry 1'];
        end
        % plotting hours restrictions
        if sameshock==0
            vv=vv+1;
            eval(['plot(irfx,exp(irfold.rechours.Psii_' num2str(pp) '(1+irfx)).*48,''Color'',colorsset(' num2str(vv) ',:),''Linewidth'',3)'])
            hold on
        end
    end
    legend(legendset{2:end},'Location','North')
    xlabel('Month')
    ylabel('Expected path for hours per worker by industry')
    xlim([0 maxplotlen])
    ylim([38 50])
    hold off

    filename  = ['input-files/irf-franceGD-hours-expected' save_handle_new];
    save_file = ['../Output/' filename];
    export_fig([save_file '.eps'],'-transparent');
    figprop.headtitle   =   ['Impulse Response Functions of Hours Per Capita'];
    figprop.label   =   ['fig:' filename];
    TexFigure(save_file,[filename '.eps'],'replace',figprop);
    save_file_set   =   [save_file_set ' ' filename '.tex'];
    clear figprop;
    
    
    eval(['load Dynare/franceGD_simul' save_handle '_' solve_set{kk} '.mat'])
end    
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%              Figure 2: Impulse response functions
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

plotset={'Y','P','C','I'};
plottilte={'Output','Price level','Consumption','Investment'};

hFig = figure;
set(hFig, 'Position', [100 100 1000 600]);
for ii=1:length(plotset)
%     ['plot(irfx,exp(irf.hourscond.Psii_' num2str(pp) '(1+irfx)).*48,colors(' num2str(pp) ',:),''Linewidth'',3)']
    eval(['subplot(2,2,ii), plot(irfx,(exp(irf.hourscond.' plotset{ii} '(1+irfx))./exp(irf.hourscond.' plotset{ii} '(1))-1)*100,''b-'',''Linewidth'',3)'])
    hold on
    eval(['subplot(2,2,ii), plot(irfx,zeros(1,length(irfx)),''k:'',''Linewidth'',2)'])
    xlabel('Month')
    ylabel([plottilte{ii} ' (% from steady-state)'])
    xlim([0 maxplotlen])
end


filename  = ['input-files/irf-franceGD-irf' save_handle_new];
save_file = ['../Output/' filename];
export_fig([save_file '.eps'],'-transparent');
figprop.headtitle   =   ['Impulse Response Functions'];
figprop.label   =   ['fig:' filename];
TexFigure(save_file,[filename '.eps'],'replace',figprop);
save_file_set   =   [save_file_set ' ' filename '.tex'];
clear figprop;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%              Figure 2a: Impulse response functions
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

plotset={'Y','C','I'};
plottilte={'Output','Consumption','Investment'};

hFig = figure;
set(hFig, 'Position', [100 100 600 400]);
for ii=1:length(plotset)
    eval(['plot(irfx,(exp(irf.hourscond.' plotset{ii} '(2+irfx))./exp(irf.hourscond.' plotset{ii} '(1))-1)*100,' styleset3{ii} ',''Linewidth'',3)'])
    hold on
end
plot(irfx,zeros(1,length(irfx)),'k:','Linewidth',2)
xlabel('Month')
ylabel(['% deviation from steady-state'])
legend(plottilte,'Location','NorthEast')
xlim([0 maxplotlen])

filename  = ['input-files/irf-franceGD-irf-a' save_handle_new];
save_file = ['../Output/' filename];
export_fig([save_file '.eps'],'-transparent');
figprop.headtitle   =   ['Impulse Response Functions'];
figprop.label   =   ['fig:' filename];
TexFigure(save_file,[filename '.eps'],'replace',figprop);
save_file_set   =   [save_file_set ' ' filename '.tex'];
clear figprop;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%              Figure 2b: Impulse response functions
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

plotset={'P'};
plottilte={'Price Level'};

hFig = figure;
set(hFig, 'Position', [100 100 600 400]);
for ii=1:length(plotset)
    eval(['plot(irfx,(exp(irf.hourscond.' plotset{ii} '(2+irfx))./exp(irf.hourscond.' plotset{ii} '(1))-1)*100,' styleset3{ii} ',''Linewidth'',3)'])
    hold on
end
plot(irfx,zeros(1,length(irfx)),'k:','Linewidth',2)
xlabel('Month')
ylabel(['% deviation from steady-state'])
legend(plottilte,'Location','NorthEast')
xlim([0 maxplotlen])

filename  = ['input-files/irf-franceGD-irf-b' save_handle_new];
save_file = ['../Output/' filename];
export_fig([save_file '.eps'],'-transparent');
figprop.headtitle   =   ['Impulse Response Functions'];
figprop.label   =   ['fig:' filename];
TexFigure(save_file,[filename '.eps'],'replace',figprop);
save_file_set   =   [save_file_set ' ' filename '.tex'];
clear figprop;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%              Figure 2c: Impulse response functions
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

plotset={'Y','C','I','P'};
plottilte={'Output','Consumption','Investment','Price Level'};

hFig = figure;
set(hFig, 'Position', [100 100 600 400]);
for ii=1:length(plotset)
    eval([plotset{ii} 'temp = (exp(irf.hourscond.' plotset{ii} '(2+irfx))./exp(irf.hourscond.' plotset{ii} '(1))-1)*100;'])
    eval(['plot(irfx,' plotset{ii} 'temp,' styleset3{ii} ',''Linewidth'',3)'])
    hold on
end
plot(irfx,zeros(1,length(irfx)),'k:','Linewidth',2)
xlabel('Month')
ylabel(['% deviation from steady-state'])
legend(plottilte,'Location','East')
xlim([0 maxplotlen])
% label output
% davinci( 'arrow', 'X', [14 7.4], 'Y', [Ytemp(8) Ytemp(8)], 'Color', 'b' ,'Head.Length' , 1, 'Head.LengthUnits','data', 'Head.Width' , 10, 'Head.WidthUnits','data', 'Shaft.Width', 1,'Shaft.WidthUnits','data', 'Head.Sweep', 0.2)
% text(14.2,Ytemp(8),'Output','fontsize',20,'Color','b')
% % davinci( 'arrow', 'X', [14 7.1], 'Y', [55 Ytemp(8)+1], 'Color', 'b' ,'Head.Length' , 5, 'Head.LengthUnits','data', 'Head.Width' , 1.5, 'Head.WidthUnits','data', 'Shaft.Width', 0.2,'Shaft.WidthUnits','data', 'Head.Sweep', 2)
% % text(14,57,'Output','fontsize',20,'Color','b')
% % label consumption
% davinci( 'arrow', 'X', [6 6], 'Y', [-25 Ctemp(7)-4], 'Color', 'r' ,'Head.Length' , 5, 'Head.LengthUnits','data', 'Head.Width' , 1.5, 'Head.WidthUnits','data', 'Shaft.Width', 0.2,'Shaft.WidthUnits','data', 'Head.Sweep', 2)
% text(1,-29,'Consumption','fontsize',20,'Color','r')
% % label investment
% davinci( 'arrow', 'X', [13 8.4], 'Y', [Itemp(9) Itemp(9)], 'Color', 'g' ,'Head.Length' , 1, 'Head.LengthUnits','data', 'Head.Width' , 10, 'Head.WidthUnits','data', 'Shaft.Width', 1,'Shaft.WidthUnits','data', 'Head.Sweep', 0.2)
% text(13.2,Itemp(9),'Investment','fontsize',20,'Color','g')
% % label price level
% davinci( 'arrow', 'X', [15 15], 'Y', [160 Ptemp(16)-4], 'Color', 'k' ,'Head.Length' , 5, 'Head.LengthUnits','data', 'Head.Width' , 1.5, 'Head.WidthUnits','data', 'Shaft.Width', 0.2,'Shaft.WidthUnits','data', 'Head.Sweep', 2)
% text(12,156,'Price level','fontsize',20,'Color','k')

filename  = ['input-files/irf-franceGD-irf-c' save_handle_new];
save_file = ['../Output/' filename];
export_fig([save_file '.eps'],'-transparent');
figprop.headtitle   =   ['Impulse Response Functions'];
figprop.label   =   ['fig:' filename];
TexFigure(save_file,[filename '.eps'],'replace',figprop);
save_file_set   =   [save_file_set ' ' filename '.tex'];
clear figprop;


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%              Figure 2d: Impulse response functions
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

plotset={'Y','C','I','Pi'};
plottilte={'Output','Consumption','Investment','Inflation'};

hFig = figure;
set(hFig, 'Position', [100 100 600 400]);
for ii=1:length(plotset)
    eval([plotset{ii} 'temp = (exp(irf.hourscond.' plotset{ii} '(2+irfx))./exp(irf.hourscond.' plotset{ii} '(1))-1)*100;'])
    eval(['plot(irfx,' plotset{ii} 'temp,' styleset3{ii} ',''Linewidth'',3)'])
    hold on
end
plot(irfx,zeros(1,length(irfx)),'k:','Linewidth',2)
xlabel('Month')
ylabel(['% deviation from steady-state'])
legend(plottilte,'Location','NorthEast')
xlim([0 maxplotlen])
% label output
davinci( 'arrow', 'X', [14 7.4], 'Y', [Ytemp(8) Ytemp(8)], 'Color', 'b' ,'Head.Length' , 1, 'Head.LengthUnits','data', 'Head.Width' , 10, 'Head.WidthUnits','data', 'Shaft.Width', 1,'Shaft.WidthUnits','data', 'Head.Sweep', 0.2)
text(14.2,Ytemp(8),'Output','fontsize',20,'Color','b')
% davinci( 'arrow', 'X', [14 7.1], 'Y', [55 Ytemp(8)+1], 'Color', 'b' ,'Head.Length' , 5, 'Head.LengthUnits','data', 'Head.Width' , 1.5, 'Head.WidthUnits','data', 'Shaft.Width', 0.2,'Shaft.WidthUnits','data', 'Head.Sweep', 2)
% text(14,57,'Output','fontsize',20,'Color','b')
% label consumption
davinci( 'arrow', 'X', [6 0.4], 'Y', [Ctemp(1) Ctemp(1)], 'Color', 'r' ,'Head.Length' , 1, 'Head.LengthUnits','data', 'Head.Width' , 10, 'Head.WidthUnits','data', 'Shaft.Width', 1,'Shaft.WidthUnits','data', 'Head.Sweep', 0.2)
text(6.2,Ctemp(1),'Consumption','fontsize',20,'Color','r')
% label investment
davinci( 'arrow', 'X', [13 8.4], 'Y', [Itemp(9) Itemp(9)], 'Color', 'g' ,'Head.Length' , 1, 'Head.LengthUnits','data', 'Head.Width' , 10, 'Head.WidthUnits','data', 'Shaft.Width', 1,'Shaft.WidthUnits','data', 'Head.Sweep', 0.2)
text(13.2,Itemp(9),'Investment','fontsize',20,'Color','g')
% label inflation
davinci( 'arrow', 'X', [3 3], 'Y', [-25 Pitemp(4)-4], 'Color', 'k' ,'Head.Length' , 5, 'Head.LengthUnits','data', 'Head.Width' , 1.5, 'Head.WidthUnits','data', 'Shaft.Width', 0.2,'Shaft.WidthUnits','data', 'Head.Sweep', 2)
text(1,-32,'Inflation','fontsize',20,'Color','k')

filename  = ['input-files/irf-franceGD-irf-d' save_handle_new];
save_file = ['../Output/' filename];
export_fig([save_file '.eps'],'-transparent');
figprop.headtitle   =   ['Impulse Response Functions'];
figprop.label   =   ['fig:' filename];
TexFigure(save_file,[filename '.eps'],'replace',figprop);
save_file_set   =   [save_file_set ' ' filename '.tex'];
clear figprop;

% stop here;


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%              Plotting NK elements
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% plotvars = var_names;
% 
% nvar=length(plotvars);
% nmax=12;
% cmax=floor(nvar/nmax);
% 
% for jj=1:cmax+(cmax*nmax<nvar)
%     
%     hFig = figure;
%     set(hFig, 'Position', [100 100 1000 600]);
%         
%     for kk=1:length(solve_set)
%         
%         % final variable number in plot
%         nmaxn=nmax;
%         if jj==cmax+1
%             nmaxn=nvar-cmax*nmax;
%         end
%         
%         % plot over variables
%         for pp=1:nmaxn
%             irflen = min(irflen,length(oo_.endo_simul(1,:)));
%             eval(['subplot(3,4,pp), plot(irfx,exp(irf.' solve_set{kk} '.' plotvars{(jj-1)*nmax+pp} '(2+irfx))./exp(irf.' solve_set{kk} '.' plotvars{(jj-1)*nmax+pp} '(1))*100,' styleset3{kk} ',''Linewidth'',3) '])
%             hold on
%             title(plotvars{(jj-1)*nmax+pp})
%         end
%         if kk==length(solve_set)
%            legend(solve_set)
%            hold off
%         end
%         
%     end
% 
%     filename  = ['input-files/irf-franceGD-' save_handle_new '-' num2str(jj) ];
%     save_file = ['../Output/' filename];
%     export_fig([save_file '.eps'],'-transparent');
%     figprop.headtitle   =   ['Impulse Response Functions in Deterministic Simulation'];
%     figprop.label   =   ['fig:' filename];
%     TexFigure(save_file,[filename '.eps'],'replace',figprop);
%     save_file_set   =   [save_file_set ' ' filename '.tex'];
%     clear figprop;
%   
% end

% save_file_set



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%              Cross-sectional regression
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% collecting data
Tmax = max(path.rest_set)+4;
YY=[];
NN=[];
HH=[];
HC=[];
TFE=[];
IFE=zeros(Tmax*option.nn,option.nn-1);

for pp=1:option.nn
    % y-variable: industry-output
    eval(['YY = [YY; transpose(irf.rechours.Yi_' num2str(pp) '(1:Tmax)-[irf.rechours.Yi_' num2str(pp) '(1),irf.rechours.Yi_' num2str(pp) '(1:Tmax-1)]) ];'])
    eval(['NN = [NN; transpose(irf.rechours.Ni_' num2str(pp) '(1:Tmax)-[irf.rechours.Ni_' num2str(pp) '(1),irf.rechours.Ni_' num2str(pp) '(1:Tmax-1)]) ];'])
    eval(['HC = [HC; transpose(irf.rechours.Hpci_' num2str(pp) '(1:Tmax)-[irf.rechours.Hpci_' num2str(pp) '(1),irf.rechours.Hpci_' num2str(pp) '(1:Tmax-1)]) ];'])
    
    
    % x-variable: hours restriction
    HH1 =   zeros(Tmax,1);
    HH1(path.rest_set(pp)+1) = 1;
    eval(['HH = [HH; HH1 ];'])
    
    % industry FE
    if pp<option.nn
        IFE(1+(pp-1)*Tmax:pp*Tmax,pp) = ones(Tmax,1);
    end
    
    % time FE
    TFE = [TFE; eye(Tmax)];
end

% percent growth
YY  =   YY.*100;
NN  =   NN.*100;
HC  =   HC.*100;
% YY
% HH
% TFE
% IFE

% running regression
[b,bint] = regress(YY,[HH,TFE,IFE]);
disp(['Cross-sectional regression coefficient on output: ' num2str(b(1))])
disp(['95\% CI: ' num2str(bint(1,:))])
b(1)
bint(1,:)

[b2,bint2] = regress(NN,[HH,TFE,IFE]);
disp(['Cross-sectional regression coefficient on employment: ' num2str(b2(1))])
disp(['95\% CI: ' num2str(bint2(1,:))])
b2(1)
bint2(1,:)

[b3,bint3] = regress(HC,[HH,TFE,IFE]);
disp(['Cross-sectional regression coefficient on hours: ' num2str(b3(1))])
disp(['95\% CI: ' num2str(bint3(1,:))])
b3(1)
bint3(1,:)

% [YY,HH,TFE,IFE]
% [NN,HH,TFE,IFE]

% YY(5)
% YY(Tmax+5)
% 
% YY(8)
% YY(Tmax+8)
% b = regress(YY,[HH,IFE])

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%              Figure 3: robustness plot
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

maxplotlen=12;
irflen=maxplotlen+1;
irfx=0:1:maxplotlen;

if strcmp(robustplot,'on')
    
    robset = {'','response','wrigid','pindex','habit','actual'};
    roblegend = {'Baseline','Empirical nominal interest rate response','Rigid wages','Price indexation','Consumption habits','Actual hours decline'};
    
    hFig = figure;
    set(hFig, 'Position', [100 100 600 400]);
    Ytemp = (exp(irf.hourscond.Y(2+irfx))./exp(irf.hourscond.Y(1))-1)*100;
    eval(['plot(irfx,Ytemp,' styleset3{1} ',''Linewidth'',3)'])
    hold on
    
    for zz=2:length(robset)
        
        eval(['load ../Output/simulation/franceGD_simul' save_handle robset{zz} '.mat irf'])
        
        Ytemp = (exp(irf.hourscond.Y(2+irfx))./exp(irf.hourscond.Y(1))-1)*100;
        eval(['plot(irfx,Ytemp,' styleset3{zz} ',''Linewidth'',3)'])

    end
    
    plot(irfx,zeros(1,length(irfx)),'k:','Linewidth',2)
    hold off
    xlabel('Month')
    ylabel(['Output: % deviation from steady-state'])
    legend(roblegend,'Location','NorthEast')
    xlim([0 maxplotlen])
    
    filename  = ['input-files/irf-franceGD-irf-robustness' save_handle_new];
    save_file = ['../Output/' filename];
    export_fig([save_file '.eps'],'-transparent');
    figprop.headtitle   =   ['Impulse Response Functions'];
    figprop.label   =   ['fig:' filename];
    TexFigure(save_file,[filename '.eps'],'replace',figprop);
    save_file_set   =   [save_file_set ' ' filename '.tex'];
    clear figprop;
    
    eval(['load ../Output/simulation/franceGD_simul' save_handle '.mat irf'])
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%              Saving output
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% EmbedTex(['../Output/output-' save_handle],save_file_set,'replace','landscape')


end



