function [vars_ss,var_exo] = franceGD_steady(para,option)
% Calculates steady-state for NKDMP model


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%               Loading structures
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%Creating variables from the parameter structure
para_names     =   fieldnames(para);
np=length(para_names);
for ii=1:np
    eval([para_names{ii} '=para.' para_names{ii} ';']);
end;

%Creating variables from the parameter structure
option_names     =   fieldnames(option);
np=length(option_names);
for ii=1:np
    eval([option_names{ii} '=option.' option_names{ii} ';']);
end;


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%               Minimization: solving for steady-state labor supply
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

options_set = optimset('MaxFunEvals',200000,'MaxIter',200000,'TolX',10^-16,'TolFun',10^-16);

% non-linear solver to find steady-state
x0  =   1;
f1 = @(x)f_franceGD_steady_solve(x,para);
[x1,fval] = fminunc(f1,x0,options_set);


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%               Implied variables: Aggregate
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% steady-state labor
vars_ss.N   =   x1;

% nominal interest rate
vars_ss.R   =   betta^-1;
vars_ss.RStar   =   vars_ss.R;

% inflation
vars_ss.Pi  =   1;

% real return on capital
vars_ss.Rk  =   vars_ss.R-1+delta;

% real wage
vars_ss.WP  =  ( (zetta-1)/(zetta*alfabar) * a / vars_ss.Rk^alfa  )^(1/(1-alfa)) * Hbar;
% vars_ss.WPStar  =  vars_ss.WP;

% capital stock;
vars_ss.K   =   alfa/(1-alfa) * (vars_ss.WP/vars_ss.Rk) * vars_ss.N;

% output
vars_ss.Y   =   a * vars_ss.K^alfa * (vars_ss.N * Hbar)^(1-alfa);

% consumption
vars_ss.C   =   vars_ss.Y - delta*vars_ss.K;

% investment
vars_ss.I   =   delta*vars_ss.K;

% price of capital
vars_ss.Pk  =   1;

% capital adjustment costs
vars_ss.S   =   0;
vars_ss.Sd  =   0;

% marginal utility of consumption
vars_ss.lambda  =   vars_ss.C^-siggma;

% discount factor
vars_ss.Q   =   betta;

% productivity
vars_ss.a       =   a;

% interest rate wedge
vars_ss.rf  =   0;


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%               Implied variables: industry-specific
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% real variables
varset = {'N','Y','K'};
for jj=1:length(varset)
    eval(['vars_ss.' varset{jj} 'i  =  tau*vars_ss.' varset{jj} ';'])
end

% relative prices
vars_ss.Preli  =   ones(1,option.nn);

% industry-inflation
vars_ss.Pii =   ones(1,option.nn);

% industry real-wage
vars_ss.WPi =   vars_ss.WP*ones(1,option.nn);


% industry real-wage inflation
vars_ss.Piwi =   ones(1,option.nn);

% industry marginal cost
vars_ss.mui =   alfabar*vars_ss.Rk^alfa * vars_ss.WP^(1-alfa) / ( ( Psibar * Hbar )^(1-alfa) * vars_ss.a ).*ones(1,option.nn);

% industry reset price
% vars_ss.bi  =   ones(1,option.nn);

% industry recursion (1)
% vars_ss.Fi  =   (vars_ss.mui.*vars_ss.Yi)/(1-(1-xi)*vars_ss.Q);

% industry recursion (2)
% vars_ss.Hi  =   vars_ss.Yi/(1-(1-xi)*vars_ss.Q);

% price dispersion
vars_ss.Deltai  =   ones(1,option.nn);  

% industry hour-constraint
vars_ss.Psii    =   ones(1,option.nn);  

% steady-state hours;
vars_ss.Hpci  =   vars_ss.Psii*Hbar;


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%               Shock structure
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

var_exo.e_Psii  =   zeros(1,option.nn);
var_exo.e_a     =   0;
var_exo.e_rf    =   0;


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%               Saving output
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% vars_ss = rmfield(vars_ss,'WP');
save(['Steady/franceGD-' save_handle],'vars_ss','var_exo');

end