% parameters for France-Great-Depression model


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%               Baseline Parameters
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

frequency       =   12;             % 12 = monthly, 4 = quarterly

% consumer preferences
para.siggma =   1;                  % Source: middle of the range value
para.habit  =   0;                  % Habit parameter
para.etta   =   1;                  % 
para.betta  =   0.97^(1/frequency); % Average interest rate
para.tau    =   ones(1,option.nn)./option.nn;
para.zetta  =   10;                 % Elasticity of substitution across sectors
para.thetta =   10;5;1.5;           % Elasticity of substitution across industries
para.Psibar =   1;                  % Normalization
para.Hbar   =   48/120;             % Normalization
para.chi    =   1;                  % Normalization

% technology parameters
para.a      =   1;                  % Normalization
para.alfa   =   0.33;               % Source: Convention
para.delta  =   0.1/frequency;      % Source: Convention
para.psi    =   4;25;2;10;0.1;2;    % Source: Christiano-Eichenbaum-Trabandt (2014)

% pricing frictions
para.xi     =   0.2625;0.265;0.5/3;0.125;	
para.rotac  =   (para.zetta-1) * (1-para.xi)/(para.xi*(1-(1-para.xi)*para.betta)) * (1+para.zetta*para.etta*(1-para.alfa)/(1+para.alfa*para.etta));
% para.rotac  =   (para.zetta-1) * (1-para.xi)/(para.xi*(1-(1-para.xi)*para.betta));
para.pindex =   0;0.9;0.8;

% wage setting frictions
para.xi_w   =   1;0.95;0.5/3;
para.zeta_w =   5;                  % Normalization
para.phi_w  =   100;
para.phi_w  =   (para.zeta_w) * (1-para.xi_w)/(para.xi_w*(1-(1-para.xi_w)*para.betta)) ;

% policy parameters
para.phipi  =   0;2.5;
para.phiy   =   0;0.5/12;
para.ibar   =   para.betta^-1; % shooting does not converge for high ibar
para.rho_R  =   0;0.8;0.95^(1/3);

% exogenous processes
para.rho_rf     =   0.95;
para.rho_a      =   1;
para.rho_Psii   =   1;
para.lawdur     =   24;
para.law40      =   log(0.833333333333333);

% implied parameters
para.alfabar = para.alfa^(-para.alfa)*(1-para.alfa)^(-(1-para.alfa));

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%      Update parameters given various options
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% update parameters if we use a longer expected duration
if strcmp(option.initval,'on')==1
    para.rho_Psii   =   0.917;
    para.xi     =   0.2266;	
end

% update parameters if we use a smaller shock
if strcmp(option.lawmatch,'actual')==1
    para.law40      =   log(0.88);
    para.xi         =   0.3475;	
end

% update parameters if we have habits
if strcmp(option.habit,'habit')==1
    para.habit      =   0.833;0.7^(1/3);
    para.xi         =   0.22315675;
end

% update parameters if we have price indexation
if strcmp(option.pindex,'pindex')==1
    para.pindex	=   0.5;
    para.xi     =   0.191;	
end

% update parameters if rigid wages
if strcmp(option.wrigid,'wrigid')==1
    para.xi_w   =   0.33;0.95;0.5/3;
    para.phi_w  =   (para.zeta_w) * (1-para.xi_w)/(para.xi_w*(1-(1-para.xi_w)*para.betta)) ;
    para.xi     =   0.2696;	
end

% update parameters if interest rate response
if strcmp(option.response,'response')==1
%     para.phipi  =   0.1;
%     para.xi     =   0.2686;	
    para.phipi  =   0.075;
    para.xi     =   0.267;	
end

% new price rigidity
para.rotac  =   (para.zetta-1) * (1-para.xi)/(para.xi*(1-(1-para.xi)*para.betta)) * (1+para.zetta*para.etta*(1-para.alfa)/(1+para.alfa*para.etta));

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%      Hours restriction path, recession depth, and plot settings
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% transition path
path.maxiter         =   2000;
path.simullen        =   600;
path.maxplotlen      =   36;
path.irflen          =   36;

% hours restriction path
if option.nn==2
    path.rest_set = [2,4,6,8];
elseif option.nn==4
    path.rest_set = [2,4,6,8];
elseif option.nn==6
    path.rest_set = [2,4,6,8,10,12]; 
    path.rest_set = [5,7,9,11,13,15]; 
elseif option.nn==7
    path.rest_set = [5,7,9,11,13,15,17];
    path.rest_set = [5,7,9,11,13,15,17];
elseif option.nn==13
    path.rest_set = [5,6,7,8,9,10,11,12,13,14,15,16,17]; 
elseif option.nn==22
    path.rest_set = [5*ones(1,8),6*ones(1,2),7*ones(1,6),8*ones(1,2),9,10,11,13];
else
    path.rest_set = 4+ones(1,option.nn);
end
for ii=1:length(path.rest_set)
    eval(['path.start.e_Psii_' num2str(ii) '    =   ' num2str(path.rest_set(ii)) ';'])
    eval(['path.fin.e_Psii_' num2str(ii) '      =   path.start.e_Psii_1 + para.lawdur;'])
    eval(['path.depth.e_Psii_' num2str(ii) '     =   para.law40;'])
    if para.rho_Psii~=1
        eval(['path.repeat.e_Psii_' num2str(ii) '      =   (1-para.rho_Psii)*path.depth.e_Psii_' num2str(ii) ';']);
    else
        eval(['path.repeat.e_Psii_' num2str(ii) '      =   0;']);
    end
end


% recession path
path.start.e_rf     =   1;
path.fin.e_rf       =   0;
path.depth.e_rf     =   0;0.015;0.02;0.025;       % recession depth
path.repeat.e_rf    =   0;

% technology path
path.start.e_a      =   1;
path.fin.e_a        =   8;
path.depth.e_a      =   0;
path.repeat.e_a     =   0;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%               Saving output
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

save('../Parameters/parameters','para','path');