//This graphs annual GDP and industrial production in France 1928-1938;

clear all
set more off
#delimit;
version 13;

*change path as necessary;
local locpath "~/Dropbox/Spring33/Cohen-Setton_Hausman_Wieland_data_programs";
local savpath "`locpath'/Stata/Data/";
local outpath "`locpath'/Stata/Output/";
local imppath "`locpath'/Data/";

qui: cd "`imppath'";


*Use Villa GDP data;
import excel using "`imppath'/long.xls", first;


*fix variable names; 
*To make the below work need to label the first column;
label var A "series";

foreach var of varlist _all {;
        local label : variable label `var';
        local new_name = lower(strtoname("`label'"));
		rename `var' `new_name';
	};

rename (_*) (data*);

reshape long data, j(year) i(series);

*keep only GDP;
keep if series =="PIBVOL";
drop series;
rename data real_gdp;

save "`savpath'villa_rgdp_expen", replace;

*Now get Villa IP data;
drop _all;

import excel using "`imppath'/industry.xls", first;

gen date = monthly(A, "YM");
format date %tm;
gen year = yofd(dofm(date));


collapse IPIND, by(year);
rename IPIND ip;

merge 1:1 year using "`savpath'villa_rgdp_expen";

//re-index both series to be 100 in 1929;
local indexyear	=	"1929" ;
local firstyear = year[1];
local obs1929 = `indexyear' - `firstyear' +1;
local serieslist "real_gdp ip";

foreach series of local serieslist {;
	gen `series'_index = 100*(`series' / `series'[`obs1929']);
	*check;
	assert abs(`series'_index - 100) <0.00001 if year==1929 ;
	};

	
	
tsset year;

*do a couple checks of the data before graphing;
local tol  = 0.000001;

assert abs((ip_index/l.ip_index -1) - 0.007168438 < `tol') if year==1930;
assert abs((real_gdp_index/l.real_gdp_index -1) - -0.026694712< `tol') if year==1936;
	
	
tsline real_gdp_index ip_index if tin(1928, 1938), lpattern(l "-") legend(label(1 "Real GDP") ///
label(2 "Industrial production")) ttitle("Year") ytitle("Annual index, 1929=100") ///
   ylabel(,nogrid) graphregion(color(white));
   
graph export "`outpath'france_gdp_ip.pdf", replace;
