/*This seasonally adjusts and graphs aggregate working hours. */

clear all
set more off
#delimit;
version 13;

* Change this path to directory on your computer;
local locpath "~/Dropbox/Spring33/Cohen-Setton_Hausman_Wieland_data_programs";
local savpath "`locpath'/Stata/Data/";
local outpath "`locpath'/Stata/Output/";
local imppath "`locpath'/Data/";

qui: cd "`imppath'";

*local for assert checks;
local tol = 0.000001;


*Get data;
import excel "`imppath'work_time.xlsx", sheet(data) firstrow;

gen year = year(date);
gen month_dum = month(date);
drop date;
gen date = ym(year,month);
format date %tm;
tsset date;

rename overall hours;
keep date hours month_dum;

*seasonally adjust;
gen hours_sa = hours;
qui xi, noomit prefix(_) i.month_dum;
qui arima hours _month_dum_* , ar(1) ma(1) noconstant;
		
/*Subtract month dummy from SA unemployed*/
local unitmean = 0;
forvalues mm = 1/12 {;
	replace hours_sa = hours_sa  - _b[_month_dum_`mm'] if month_dum==`mm'; 
	local unitmean = `unitmean' + _b[_month_dum_`mm'];
		}; 

local unitmean = `unitmean'/12;  

/*Add back mean of month dummy to SA variable*. */
replace hours_sa = hours_sa + `unitmean'; 

save "`savpath'/weekly_hours", replace;
	
*graph for paper;
tsline hours_sa if tin(1935m1, 1939m8), tline(1936m11) tline(1938m11) yline(40, lpattern("-")) lpattern(l "-") ///
legend(off) ttitle("Date") ytitle("Weekly hours (s.a.)") ///
   ylabel(,nogrid) graphregion(color(white)) || pcarrowi 41.5 `=tm(1936m11)-3' 42 `=tm(1936m11)' (8) "40-hour law begins"  45 `=tm(1938m11)-3' 44.5 `=tm(1938m11)' (10) "40-hour law ends", mcolor(red) lcolor(red) mlabcolor(red);

graph export "`outpath'/weekly_hours.pdf", replace;

 

 
 
