#delimit;
clear all;
set more off;
set matsize 10000;
version 13;


/*************************************************************************************************************
This do-file reads depression data on European countries from Mitchell (1981). 
*************************************************************************************************************/

/*Generate paths. Change path below if using on a different computer. */
local locpath "~/Dropbox/Spring33/Cohen-Setton_Hausman_Wieland_data_programs";
local savpath "`locpath'/Stata/Data/";
local outpath "`locpath'/Stata/Output/";
local imppath "`locpath'/Data/";

local dataseries "ip wp";

qui: cd "`imppath'";


* Import data;
foreach series of local dataseries {;

	import excel "`imppath'mitchell_ip_prices.xlsx", sheet("`series'") firstrow case(lower);
	rename year date;
	
	foreach var of varlist * {;
		if `var' != date {;
			local country "`var'";
			rename `var' `series'`country';
		};
	};
	
	reshape long `series', i(date) j(country) string;
	
	cd "`savpath'";
	save int_`series', replace;
	drop _all;

	
	};
	


*get gold standard dates - already in long format;
import excel "`imppath'mitchell_ip_prices.xlsx", sheet("gold_standard") firstrow case(lower);	
rename year date;
replace country = lower(country);
save int_gs_dates, replace;
drop _all;

*get U.S. IP and price data from FRED;
freduse INDPRO PPIACO;

drop date;
gen date = yofd(daten);
drop if date < 1925 | date > 1940;

rename INDPRO ip;
rename PPIACO wp;

collapse ip wp, by(date);

gen country = "usa";
save us_data, replace;
drop _all;	
	
* merge / append data;
use int_ip;
merge 1:1 date country using int_wp, gen(_mergewp);
append using us_data;

*tostring date, force replace;
merge 1:1 date country using int_gs_dates, gen(_merge_gs_dates);
encode country, gen(countrycd);
xtset countrycd date;

gen leave_gs = 0;
replace leave_gs =1 if gold_standard==1 & F.gold_standard==0;
gen leave_gs_temp = date if leave_gs==1;
by countrycd, sort: egen leave_gs_date = min(leave_gs_temp);


foreach series of local dataseries {;

	gen lgs`series'_t  = `series' if leave_gs==1;
	by countrycd, sort: egen lgs`series'_t2 = min(lgs`series'_t);
	gen lgs`series' = 100*(`series'/lgs`series'_t2);
	
    gen b29`series'_t = `series' if date==1929;
	by countrycd, sort: egen b29`series'_t2 = min(b29`series'_t);
	
	*percent changes for use in graph;
	gen `series'_1yr_pch = 100*(`series' / L.`series' -1);
	gen `series'_2yr_pch = 100*(`series' / L2.`series' -1);
	gen `series'_3yr_pch = 100*(`series' / L3.`series' -1);
	
	*percent change 1929 to devaluation;
	gen `series'_29lgs_pch = 100*(lgs`series'_t2 / b29`series'_t2 -1);

	
};

gen lgs_dat   = .;
	replace lgs_dat   = 0 if leave_gs==1;
	forvalues jj=1(1)4 {;
		replace lgs_dat=-`jj' if F`jj'.leave_gs==1;
		replace lgs_dat=`jj' if L`jj'.leave_gs==1;
		
		};


		


				
*before graphing, do some checks;
assert leave_gs ==1 if country=="usa" & date==1933;
assert leave_gs ==1 if country=="france" & date==1936;
assert ip == 90 if country=="belgium" & date==1936;
assert wp==56 if country=="france" & date==1935;		
assert abs(ip-5.0258833)<0.001 if country=="usa" & date ==1933;		
		
		
* scatter plots;
cd "`outpath'";

*Make inflation variable that is graphed;
gen pi_change = wp_2yr_pch - 100*((1+l3.wp_1yr_pch/100)^2-1);

assert abs(pi_change - 68.3725) <0.1 if country=="france" & date==1938;


*make labels;
tostring leave_gs_date, gen(leave_gs_date_string);
gen country_label = strproper(country) + " " + substr(leave_gs_date_string,3,2);


label var ip_2yr_pch "Cumulative IP growth (%)";
label var pi_change "Change in inflation (percentage points)";



*capitalize UK and USA;
replace country_label = upper(country_label) if length(country) <4;

//check statistical significace of relationship;
*w/ france;
reg ip_2yr_pch pi_change if L2.leave_gs==1;

*w/o france;
reg ip_2yr_pch pi_change if L2.leave_gs==1 & country!="france";



*IP vs. CHANGE IN inflation measured as difference between cumalative inflation and 2*inflation
*in the year before leaving the gold standard. IP is cumulative 2 year growth;
graph twoway (scatter ip_2yr_pch pi_change if L2.leave_gs==1, mlabel(country_label) mlabposition(6) xlabel(0[20]80))
(lfit ip_2yr_pch pi_change if L2.leave_gs==1 & country!="france")
(scatter ip_2yr_pch pi_change if L2.leave_gs==1 & country=="france", mlabel(country_label) ms(D) mlabposition(6) xlabel(0[20]80)),
 name(scatgs_pichange1, replace) graphregion(color(white)) legend(ring(0) pos(5) order(2 "Linear Fit Excluding France")) ylabel(, nogrid) xlabel(0[20]80);
graph export  "`outpath'scatgs_pichange2.pdf", replace;

