//This graphs monthly wage and price data from Sauvy;

#delimit;
clear all;
set more off;

* Change this path to directory on your computer;
local locpath "~/Dropbox/Spring33/Cohen-Setton_Hausman_Wieland_data_programs";
local savpath "`locpath'/Stata/Data/";
local outpath "`locpath'/Stata/Output/";
local imppath "`locpath'/Data/";

qui: cd "`imppath'";

*import data. Data was hand-entered from Sauvy (1984);
import excel using "`impath'sauvy_data.xlsx", sheet(data) firstrow; 

gen date = ym(year, month);
format date %tm;

tsset date;

*reindex to be 100 in Jan. 1935 (13th observation);
gen wp_index = 100*(wholesale_price / wholesale_price[13]);
gen wpd_index = 100*(domestic_wholesale_price / domestic_wholesale_price[13]);
gen cp_index = 100*(consumption_price / consumption_price[13]);
gen wage_index = 100*(hourly_wages / hourly_wages[13]);

*real wages, deflated by wholesale prices;
gen rw_wp = 100*(wage_index / wp_index);

*real wages deflated by domestic wholesale prices;
gen rw_wpd = 100*(wage_index / wpd_index);

*real wages, deflated by consumer prices;
gen rw_cp = 100*(wage_index / cp_index);


*12-month wholesale price inflation;
gen wp_inflation = 100*(wholesale_price / l12.wholesale_price -1);


save "`savpath'wages_prices", replace;

tsline wp_index wpd_index cp_index if tin(1935m1, 1938m12), tline(1936m5) tline(1936m9) lpattern(l "-") ///
legend(label(1 "Wholesale prices") label(2 "Domestic wholesale prices") label(3 "Consumer prices") order(1 2 3)) ttitle("Year") ///
ytitle("Index, n.s.a, 1/1935=100") ///
   ylabel(,nogrid) graphregion(color(white)) || pcarrowi 190 `=tm(1936m5)-3' 180 `=tm(1936m5)' (10) "Popular front elected"  190 `=tm(1936m9)+3' 180 `=tm(1936m9)' (3) "Devaluation", mcolor(red) lcolor(red) mlabcolor(red);
      
graph export "`outpath'/monthly_prices1.pdf", replace;


tsline wage_index rw_wpd rw_cp if tin(1935m1, 1938m12), tline(1936m5) tline(1936m9) lpattern(l "-") legend(label(1 "Nominal") ///
label(2 "Real, domestic wpi deflator") label(3 "Real, cpi deflator") order(1 2 3)) ttitle("Year") ytitle("Index, n.s.a, 1/1935=100") ///
   ylabel(,nogrid) graphregion(color(white)) || pcarrowi 170 `=tm(1936m5)-3' 160 `=tm(1936m5)' (10) "Popular front elected"  170 `=tm(1936m9)+3' 160 `=tm(1936m9)' (3) "Devaluation", mcolor(red) lcolor(red) mlabcolor(red);
   
   
graph export "`outpath'/monthly_wages1.pdf", replace;






